@@ -21,7 +21,7 @@ use crate::derives::args::collect_args_fields;
 use crate::item::{Item, Kind, Name};
 use crate::utils::{is_simple_ty, subty_if_name};
 
-pub fn derive_subcommand(input: &DeriveInput) -> Result<TokenStream, syn::Error> {
+pub(crate) fn derive_subcommand(input: &DeriveInput) -> Result<TokenStream, syn::Error> {
     let ident = &input.ident;
 
     match input.data {
@@ -43,7 +43,7 @@ pub fn derive_subcommand(input: &DeriveInput) -> Result<TokenStream, syn::Error>
     }
 }
 
-pub fn gen_for_enum(
+pub(crate) fn gen_for_enum(
     item: &Item,
     item_name: &Ident,
     generics: &Generics,
@@ -84,6 +84,7 @@ pub fn gen_for_enum(
             clippy::cargo,
             clippy::suspicious_else_formatting,
             clippy::almost_swapped,
+            clippy::redundant_locals,
         )]
         #[automatically_derived]
         impl #impl_generics clap::FromArgMatches for #item_name #ty_generics #where_clause {
@@ -117,6 +118,7 @@ pub fn gen_for_enum(
             clippy::cargo,
             clippy::suspicious_else_formatting,
             clippy::almost_swapped,
+            clippy::redundant_locals,
         )]
         #[automatically_derived]
         impl #impl_generics clap::Subcommand for #item_name #ty_generics #where_clause {
@@ -138,7 +140,7 @@ fn gen_augment(
     parent_item: &Item,
     override_required: bool,
 ) -> Result<TokenStream, syn::Error> {
-    use syn::Fields::*;
+    use syn::Fields::{Named, Unit, Unnamed};
 
     let app_var = Ident::new("__clap_app", Span::call_site());
 
@@ -182,7 +184,7 @@ fn gen_augment(
 
             Kind::Flatten(_) => match variant.fields {
                 Unnamed(FieldsUnnamed { ref unnamed, .. }) if unnamed.len() == 1 => {
-                    let ty = &unnamed[0];
+                    let ty = &unnamed[0].ty;
                     let deprecations = if !override_required {
                         item.deprecations()
                     } else {
@@ -223,7 +225,7 @@ fn gen_augment(
                     }
                     Unit => quote!( #subcommand_var ),
                     Unnamed(FieldsUnnamed { ref unnamed, .. }) if unnamed.len() == 1 => {
-                        let ty = &unnamed[0];
+                        let ty = &unnamed[0].ty;
                         if override_required {
                             quote_spanned! { ty.span()=>
                                 {
@@ -293,7 +295,7 @@ fn gen_augment(
                         }
                     }
                     Unnamed(FieldsUnnamed { ref unnamed, .. }) if unnamed.len() == 1 => {
-                        let ty = &unnamed[0];
+                        let ty = &unnamed[0].ty;
                         let arg_block = if override_required {
                             quote_spanned! { ty.span()=>
                                 {
@@ -355,7 +357,7 @@ fn gen_augment(
 }
 
 fn gen_has_subcommand(variants: &[(&Variant, Item)]) -> Result<TokenStream, syn::Error> {
-    use syn::Fields::*;
+    use syn::Fields::Unnamed;
 
     let mut ext_subcmd = false;
 
@@ -390,7 +392,7 @@ fn gen_has_subcommand(variants: &[(&Variant, Item)]) -> Result<TokenStream, syn:
         .iter()
         .map(|(variant, _attrs)| match variant.fields {
             Unnamed(ref fields) if fields.unnamed.len() == 1 => {
-                let ty = &fields.unnamed[0];
+                let ty = &fields.unnamed[0].ty;
                 Ok(quote! {
                     if <#ty as clap::Subcommand>::has_subcommand(__clap_name) {
                         return true;
@@ -419,7 +421,7 @@ fn gen_has_subcommand(variants: &[(&Variant, Item)]) -> Result<TokenStream, syn:
 }
 
 fn gen_from_arg_matches(variants: &[(&Variant, Item)]) -> Result<TokenStream, syn::Error> {
-    use syn::Fields::*;
+    use syn::Fields::{Named, Unit, Unnamed};
 
     let subcommand_name_var = format_ident!("__clap_name");
     let sub_arg_matches_var = format_ident!("__clap_arg_matches");
@@ -496,7 +498,7 @@ fn gen_from_arg_matches(variants: &[(&Variant, Item)]) -> Result<TokenStream, sy
             },
             Unit => quote!(),
             Unnamed(ref fields) if fields.unnamed.len() == 1 => {
-                let ty = &fields.unnamed[0];
+                let ty = &fields.unnamed[0].ty;
                 quote!( ( <#ty as clap::FromArgMatches>::from_arg_matches_mut(__clap_arg_matches)? ) )
             }
             Unnamed(..) => abort_call_site!("{}: tuple enums are not supported", variant.ident),
@@ -512,7 +514,7 @@ fn gen_from_arg_matches(variants: &[(&Variant, Item)]) -> Result<TokenStream, sy
         let variant_name = &variant.ident;
         match variant.fields {
             Unnamed(ref fields) if fields.unnamed.len() == 1 => {
-                let ty = &fields.unnamed[0];
+                let ty = &fields.unnamed[0].ty;
                 Ok(quote! {
                     if __clap_arg_matches
                         .subcommand_name()
@@ -570,7 +572,7 @@ fn gen_from_arg_matches(variants: &[(&Variant, Item)]) -> Result<TokenStream, sy
 }
 
 fn gen_update_from_arg_matches(variants: &[(&Variant, Item)]) -> Result<TokenStream, syn::Error> {
-    use syn::Fields::*;
+    use syn::Fields::{Named, Unit, Unnamed};
 
     let (flatten, variants): (Vec<_>, Vec<_>) = variants
         .iter()
@@ -632,7 +634,7 @@ fn gen_update_from_arg_matches(variants: &[(&Variant, Item)]) -> Result<TokenStr
         let variant_name = &variant.ident;
         match variant.fields {
             Unnamed(ref fields) if fields.unnamed.len() == 1 => {
-                let ty = &fields.unnamed[0];
+                let ty = &fields.unnamed[0].ty;
                 Ok(quote! {
                     if <#ty as clap::Subcommand>::has_subcommand(__clap_name) {
                         if let Self :: #variant_name (child) = s {
